@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
 from simmate.calculators.vasp.tasks.static_energy.materials_project import (
-    MatProjStaticEnergy,
+    MatprojStaticEnergy,
 )
 
 
-class MatProjPreBader(MatProjStaticEnergy):
+class MatprojPreBader(MatprojStaticEnergy):
     """
     Runs a static energy calculation with a high-density FFT grid under settings
     from the Materials Project. Results can be used for Bader analysis.
@@ -19,7 +19,7 @@ class MatProjPreBader(MatProjStaticEnergy):
 
     # The key thing for bader analysis is that we need a very fine FFT mesh. Other
     # than that, it's the same as a static energy calculation.
-    incar = MatProjStaticEnergy.incar.copy()
+    incar = MatprojStaticEnergy.incar.copy()
     incar.update(
         NGXF__density_a=20,
         NGYF__density_b=20,
